@@ -1,7 +1,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-24 10:42:34
-:LastEditTime: 2022-12-07 18:53:09
+:LastEditTime: 2022-12-08 10:48:47
 :LastEditors: HuangJingCan
 :Description: StudioBaseHandler
 """
@@ -73,6 +73,18 @@ class StudioBaseHandler(BaseCookieHandler):
             rep_dic = rep_dic.__dict__
         return json.dumps(rep_dic, ensure_ascii=False, cls=JsonEncoder)
 
+    def json_loads(self, rep_str):
+        """
+        :description: 将Json字符串解码成python对象
+        :param rep_str：str
+        :return: dict
+        :last_editors: HuangJingCan
+        """
+        try:
+            return json.loads(rep_str)
+        except Exception as ex:
+            return json.loads(self.json_dumps(rep_str))
+
     def response_custom(self, rep_dic):
         """
         :description: 输出公共json模型
@@ -363,6 +375,12 @@ class StudioBaseHandler(BaseCookieHandler):
         else:
             UserLoginModel(config.get_value("manage_context_key")).del_entity("UserID=%s", user_id)
 
+        self.clear_user_cookie()
+
+    def clear_user_cookie(self):
+        """
+        :description: 清理用户登录cookie
+        """
         self.clear_cookie("UserID")
         self.clear_cookie("UserIDMD5")
         self.clear_cookie("UserToken")
@@ -461,18 +479,14 @@ class StudioBaseHandler(BaseCookieHandler):
             if not user_login or TimeHelper.format_time_to_datetime(user_login["ExpireTime"]) < TimeHelper.get_now_datetime():
                 if not is_need_login:
                     return invoke_result
-                self.clear_cookie("UserID")
-                self.clear_cookie("UserIDMD5")
-                self.clear_cookie("UserToken")
+                self.clear_user_cookie()
                 invoke_result.ResultCode = "login_expire"
                 invoke_result.ResultMessage = "用户已过期，请重新登录"
                 return invoke_result
             if user_login["UserToken"] != user_token:
                 if not is_need_login:
                     return invoke_result
-                self.clear_cookie("UserID")
-                self.clear_cookie("UserIDMD5")
-                self.clear_cookie("UserToken")
+                self.clear_user_cookie()
                 invoke_result.ResultCode = "login_expire"
                 invoke_result.ResultMessage = "用户在其他终端登录，请重新登录"
                 return invoke_result
@@ -492,18 +506,14 @@ class StudioBaseHandler(BaseCookieHandler):
             if not user_login or TimeHelper.format_time_to_datetime(user_login.ExpireTime) < TimeHelper.get_now_datetime():
                 if not is_need_login:
                     return invoke_result
-                self.clear_cookie("UserID")
-                self.clear_cookie("UserIDMD5")
-                self.clear_cookie("UserToken")
+                self.clear_user_cookie()
                 invoke_result.ResultCode = "login_expire"
                 invoke_result.ResultMessage = "用户已过期，请重新登录"
                 return invoke_result
             if user_login.UserToken != user_token:
                 if not is_need_login:
-                    return
-                self.clear_cookie("UserID")
-                self.clear_cookie("UserIDMD5")
-                self.clear_cookie("UserToken")
+                    return invoke_result
+                self.clear_user_cookie()
                 invoke_result.ResultCode = "login_expire"
                 invoke_result.ResultMessage = "用户在其他终端登录，请重新登录"
                 return invoke_result
