@@ -1,7 +1,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-03-24 19:48:05
-:LastEditTime: 2022-12-06 09:47:05
+:LastEditTime: 2022-12-08 10:42:51
 :LastEditors: HuangJingCan
 :Description: 
 """
@@ -114,7 +114,7 @@ class LoginPlatformHandler(StudioBaseHandler):
             invoke_result.ResultMessage = "对不起你的帐号已经被锁定，请联系管理员解除限制"
             return invoke_result
 
-        is_super = user_info.IsSuper == 1
+        # is_super = user_info.IsSuper == 1
 
         if manage_context_key != base_manage_context_key:
             user_info_model_part = UserInfoModel(manage_context_key)
@@ -128,7 +128,7 @@ class LoginPlatformHandler(StudioBaseHandler):
                 invoke_result.ResultMessage = "对不起你的帐号已经被锁定，请联系管理员解除限制"
                 return invoke_result
 
-            is_super = user_info_curr.IsSuper == 1 or user_info.IsSuper == 1
+            # is_super = user_info_curr.IsSuper == 1 or user_info.IsSuper == 1
 
         # if is_platform and not is_super:
         #     role_user_list = RoleUserModel(manage_context_key).get_list("UserID=%s", params=user_info.UserID)
