@@ -2,8 +2,8 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-12-09 19:11:51
-:LastEditTime: 2020-12-25 10:04:04
-:LastEditors: ChenXiaolei
+:LastEditTime: 2022-12-08 10:13:51
+:LastEditors: HuangJingCan
 :Description: 
 """
 
@@ -23,8 +23,11 @@ class BaseSettingsHandler(StudioBaseHandler):
         login_logo = self.get_param("login_logo")
         banner_logo = self.get_param("banner_logo")
         title = self.get_param("title")
+        login_expire = int(self.get_param("login_expire", 2))
 
-        settings_base = SettingsBaseModel().get_entity("")
+        settings_base_model = SettingsBaseModel(config.get_value("manage_context_key"))
+
+        settings_base = settings_base_model.get_entity()
 
         if not settings_base:
             settings_base = SettingsBase()
@@ -33,11 +36,16 @@ class BaseSettingsHandler(StudioBaseHandler):
         settings_base.login_logo = login_logo
         settings_base.banner_logo = banner_logo
         settings_base.title = title
+        settings_base.login_expire = login_expire
 
         if settings_base.id > 0:
-            SettingsBaseModel().update_entity(settings_base)
+            settings_base_model.update_entity(settings_base)
         else:
-            SettingsBaseModel().add_entity(settings_base)
+            settings_base_model.add_entity(settings_base)
+
+        if config.get_value("login_type") == "redis":
+            redis_init = self.redis_init()
+            settings_base = redis_init.delete("settings_base")
 
         return self.response_json_success(settings_base)
 
@@ -47,9 +55,18 @@ class BaseSettingsHandler(StudioBaseHandler):
         :return 基础信息
         :last_editors: ChenXiaolei
         """
-        settings_base = SettingsBaseModel().get_dict("")
+        settings_base_model = SettingsBaseModel(config.get_value("manage_context_key"))
 
-        if not settings_base:
-            return self.response_json_success(None)
+        settings_base = None
+        if config.get_value("login_type") == "redis":
+            redis_init = self.redis_init()
+            settings_base = redis_init.get("settings_base")
+            if not settings_base:
+                settings_base = settings_base_model.get_dict()
+                redis_init.set("settings_base", self.json_dumps(settings_base))
+            else:
+                settings_base = self.json_loads(settings_base)
+        else:
+            settings_base = settings_base_model.get_dict()
 
-        return self.response_json_success(settings_base)
+        return self.response_json_success(settings_base)
\ No newline at end of file
