@@ -1,4 +1,3 @@
-
 #此文件由rigger自动生成
 from seven_framework.mysql import MySQLHelper
 from seven_framework.base_model import *
@@ -12,9 +11,9 @@ class SettingsBaseModel(BaseModel):
         self.db_transaction = db_transaction
 
     #方法扩展请继承此类
-    
-class SettingsBase:
 
+
+class SettingsBase:
     def __init__(self):
         super(SettingsBase, self).__init__()
         self.id = 0  # 自增id
@@ -22,15 +21,15 @@ class SettingsBase:
         self.login_logo = ""  # 登录页logo
         self.banner_logo = ""  # 首页顶部logo
         self.title = ""  # 标题
+        self.login_expire = ""  # 过期时间(小时)
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'login_background', 'login_logo', 'banner_logo', 'title']
-        
+        return ['id', 'login_background', 'login_logo', 'banner_logo', 'title', 'login_expire']
+
     @classmethod
     def get_primary_key(self):
         return "id"
 
     def __str__(self):
         return "cms_settings_base_tb"
-    
\ No newline at end of file
